@@ -1,11 +1,11 @@
-from qtpy.QtWidgets import (QVBoxLayout, QDialog, QDialogButtonBox, QTextEdit)
+from qtpy.QtWidgets import QVBoxLayout, QDialog, QDialogButtonBox, QTextEdit
 
 import logging
+
 logger = logging.getLogger(__name__)
 
 
 class DialogViewMetadata(QDialog):
-
     def __init__(self):
 
         super().__init__()
@@ -17,8 +17,7 @@ class DialogViewMetadata(QDialog):
         self.te_meta.setReadOnly(True)
 
         # 'Close' button box
-        button_box = QDialogButtonBox(
-            QDialogButtonBox.Close)
+        button_box = QDialogButtonBox(QDialogButtonBox.Close)
         button_box.accepted.connect(self.accept)
         button_box.rejected.connect(self.reject)
 
